<?php
/**
 * Author: lf
 * Blog: https://blog.feehi.com
 * Email: job@feehi.com
 * Created at: 2017-12-05 12:47
 */

namespace cms\backend\models\form;

use yii;
use common\libs\Constants;
use yii\helpers\FileHelper;
use yii\web\UploadedFile;

class AdForm extends \Common\models\Options
{
    public $ad;

    public $link;

    public $desc;

    public $target = Constants::TARGET_BLANK;

    public $created_at;

    public $updated_at;

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'name' => yii::t('cms', 'Sign'),
            'input_type' => yii::t('cms', 'Ad Type'),
            'tips' => yii::t('cms', 'Description'),
            'ad' => yii::t('cms', 'Ad'),
            'link' => yii::t('cms', 'Jump Link'),
            'desc' => yii::t('cms', 'Ad Explain'),
            'autoload' => yii::t('cms', 'Status'),
            'sort' => yii::t('cms', 'Sort'),
            'target' => yii::t('cms', 'Target'),
            'created_at' => yii::t('cms', 'Created At'),
            'updated_at' => yii::t('cms', 'Updated At'),
        ];
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['name'], 'unique'],
            [
                ['name'],
                'match',
                'pattern' => '/^[a-zA-Z][0-9_]*/',
                'message' => yii::t('cms', 'Must begin with alphabet and can only includes alphabet,_,and number')
            ],
            [['name', 'tips', 'input_type'], 'required'],
            [['sort', 'autoload'], 'integer'],
            [[ 'link', 'target', 'desc'], 'string'],
            [['ad'], 'file', 'skipOnEmpty' => true, 'extensions' => 'png, jpg, jpeg, gif, webp'],
        ];
    }

    public function beforeSave($insert)
    {
        $this->type = self::TYPE_AD;
        $upload = UploadedFile::getInstance($this, 'ad');
        if ($upload !== null) {
            $uploadPath = yii::getAlias('@uploads/setting/ad/');
            if (! FileHelper::createDirectory($uploadPath)) {
                $this->addError('ad', "Create directory failed " . $uploadPath);
                return false;
            }
            $fullName = $uploadPath . date('YmdHis') . '_' . uniqid() . '.' . $upload->getExtension();
            if (! $upload->saveAs($fullName)) {
                $this->addError('ad', yii::t('cms', 'Upload {attribute} error: ' . $upload->error, ['attribute' => yii::t('cms', 'Ad')]) . ': ' . $fullName);
                return false;
            }
            $this->ad = str_replace(yii::getAlias('@frontend/web'), '', $fullName);
            $file = yii::getAlias('@frontend/web') . $this->getOldAttribute('ad');
            if( file_exists($file) && is_file($file) ) unlink($file);
        }
        $value = [];
        if( !$insert ) {
            $oldInput = $this->getOldAttribute('input_type');
            if ($this->input_type != $oldInput && in_array($oldInput, [Constants::AD_IMG, Constants::AD_VIDEO])) {
                $file = yii::getAlias('@frontend/web') . $this->getOldAttribute('ad');
                if (file_exists($file) && is_file($file)) unlink($file);
            }
            if ($upload === null) {
                if ($this->ad === '0' && $this->input_type == Constants::AD_IMG) {//删除
                    $file = yii::getAlias('@frontend/web') . $this->getOldAttribute('ad');
                    if (file_exists($file) && is_file($file)) unlink($file);
                    $this->ad = '';
                }else if($this->input_type != Constants::AD_TEXT){
                    $this->ad = $this->getOldAttribute('ad');
                }
            }
        }
        $value = array_merge($value, [
            'ad' => $this->ad,
            'link' => $this->link,
            'target' => $this->target,
            'desc' => $this->desc,
            'created_at' => $insert ? time() : $this->created_at,
            'updated_at' => time(),
        ]);
        $this->value = json_encode($value);
        return parent::beforeSave($insert); // TODO: Change the autogenerated stub
    }

    public function afterFind()
    {
        $value = json_decode($this->value);
        $this->ad = $value->ad;
        $this->link = $value->link;
        $this->desc = $value->desc;
        $this->target = $value->target;
        $this->updated_at = $value->updated_at;
        $this->created_at = $value->created_at;
        $this->setOldAttributes([
            'id' => $this->id,
            'name' => $this->name,
            'value' => $this->value,
            'input_type' => $this->input_type,
            'autoload' => $this->autoload,
            'tips' => $this->tips,
            'sort' => $this->sort,
            'ad' => $value->ad,
            'link' => $value->link,
            'desc' => $value->desc,
            'target' => $value->target,
            'created_at' => $value->created_at,
            'updated_at' => $value->updated_at,
        ]);
    }

    public function afterDelete()
    {
        if( $this->input_type != Constants::AD_TEXT ){
            $file = yii::getAlias('@frontend/web') . $this->ad;
            if( file_exists($file) && is_file($file) ) unlink($file);
        }
    }
}